@@ -10,19 +10,9 @@
 
 namespace SebastianBergmann\PHPLOC;
 
-// @codeCoverageIgnoreStart
-if (!defined('T_TRAIT')) {
-    define('T_TRAIT', 1000);
-}
-// @codeCoverageIgnoreEnd
-
 /**
  * PHPLOC code analyser.
  *
- * @author    Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright Sebastian Bergmann <sebastian@phpunit.de>
- * @license   http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link      http://github.com/sebastianbergmann/phploc/tree
  * @since     Class available since Release 1.0.0
  */
 class Analyser
@@ -30,118 +20,124 @@ class Analyser
     /**
      * @var array
      */
-    private $namespaces = array();
+    private $namespaces = [];
 
     /**
      * @var array
      */
-    private $classes = array();
+    private $classes = [];
 
     /**
      * @var array
      */
-    private $constants = array();
+    private $constants = [];
 
     /**
      * @var array
      */
-    private $possibleConstantAccesses = array();
+    private $possibleConstantAccesses = [];
 
     /**
      * @var array
      */
-    private $count = array(
-      'files'                       => 0,
-      'loc'                         => 0,
-      'lloc'                        => 0,
-      'llocClasses'                 => 0,
-      'llocFunctions'               => 0,
-      'llocGlobal'                  => 0,
-      'cloc'                        => 0,
-      'ccn'                         => 0,
-      'ccnMethods'                  => 0,
-      'interfaces'                  => 0,
-      'traits'                      => 0,
-      'classes'                     => 0,
-      'abstractClasses'             => 0,
-      'concreteClasses'             => 0,
-      'functions'                   => 0,
-      'namedFunctions'              => 0,
-      'anonymousFunctions'          => 0,
-      'methods'                     => 0,
-      'publicMethods'               => 0,
-      'nonPublicMethods'            => 0,
-      'nonStaticMethods'            => 0,
-      'staticMethods'               => 0,
-      'constants'                   => 0,
-      'classConstants'              => 0,
-      'globalConstants'             => 0,
-      'testClasses'                 => 0,
-      'testMethods'                 => 0,
-      'ccnByLloc'                   => 0,
-      'llocByNof'                   => 0,
-      'methodCalls'                 => 0,
-      'staticMethodCalls'           => 0,
-      'instanceMethodCalls'         => 0,
-      'attributeAccesses'           => 0,
-      'staticAttributeAccesses'     => 0,
-      'instanceAttributeAccesses'   => 0,
-      'globalAccesses'              => 0,
-      'globalVariableAccesses'      => 0,
-      'superGlobalVariableAccesses' => 0,
-      'globalConstantAccesses'      => 0,
-      'methodCcnMin'                => 0,
-      'methodCcnAvg'                => 0,
-      'methodCcnMax'                => 0,
-      'methodLlocMin'               => 0,
-      'methodLlocAvg'               => 0,
-      'methodLlocMax'               => 0
-    );
+    private $count = [
+        'files'                       => 0,
+        'loc'                         => 0,
+        'lloc'                        => 0,
+        'llocClasses'                 => 0,
+        'llocFunctions'               => 0,
+        'llocGlobal'                  => 0,
+        'cloc'                        => 0,
+        'ccn'                         => 0,
+        'ccnMethods'                  => 0,
+        'interfaces'                  => 0,
+        'traits'                      => 0,
+        'classes'                     => 0,
+        'abstractClasses'             => 0,
+        'concreteClasses'             => 0,
+        'functions'                   => 0,
+        'namedFunctions'              => 0,
+        'anonymousFunctions'          => 0,
+        'methods'                     => 0,
+        'publicMethods'               => 0,
+        'nonPublicMethods'            => 0,
+        'nonStaticMethods'            => 0,
+        'staticMethods'               => 0,
+        'constants'                   => 0,
+        'classConstants'              => 0,
+        'globalConstants'             => 0,
+        'testClasses'                 => 0,
+        'testMethods'                 => 0,
+        'ccnByLloc'                   => 0,
+        'llocByNof'                   => 0,
+        'methodCalls'                 => 0,
+        'staticMethodCalls'           => 0,
+        'instanceMethodCalls'         => 0,
+        'attributeAccesses'           => 0,
+        'staticAttributeAccesses'     => 0,
+        'instanceAttributeAccesses'   => 0,
+        'globalAccesses'              => 0,
+        'globalVariableAccesses'      => 0,
+        'superGlobalVariableAccesses' => 0,
+        'globalConstantAccesses'      => 0,
+        'classCcnMin'                 => 0,
+        'classCcnAvg'                 => 0,
+        'classCcnMax'                 => 0,
+        'classLlocMin'                => 0,
+        'classLlocAvg'                => 0,
+        'classLlocMax'                => 0,
+        'methodCcnMin'                => 0,
+        'methodCcnAvg'                => 0,
+        'methodCcnMax'                => 0,
+        'methodLlocMin'               => 0,
+        'methodLlocAvg'               => 0,
+        'methodLlocMax'               => 0
+    ];
 
     /**
      * @var array
      */
-    private $superGlobals = array(
-      '$_ENV' => true,
-      '$_POST' => true,
-      '$_GET' => true,
-      '$_COOKIE' => true,
-      '$_SERVER' => true,
-      '$_FILES' => true,
-      '$_REQUEST' => true,
-      '$HTTP_ENV_VARS' => true,
-      '$HTTP_POST_VARS' => true,
-      '$HTTP_GET_VARS' => true,
-      '$HTTP_COOKIE_VARS' => true,
-      '$HTTP_SERVER_VARS' => true,
-      '$HTTP_POST_FILES' => true
-    );
+    private $superGlobals = [
+        '$_ENV'             => true,
+        '$_POST'            => true,
+        '$_GET'             => true,
+        '$_COOKIE'          => true,
+        '$_SERVER'          => true,
+        '$_FILES'           => true,
+        '$_REQUEST'         => true,
+        '$HTTP_ENV_VARS'    => true,
+        '$HTTP_POST_VARS'   => true,
+        '$HTTP_GET_VARS'    => true,
+        '$HTTP_COOKIE_VARS' => true,
+        '$HTTP_SERVER_VARS' => true,
+        '$HTTP_POST_FILES'  => true
+    ];
 
     /**
      * @var array
      */
-    private $classCcn = array();
+    private $classCcn = [];
 
     /**
      * @var array
      */
-    private $classLloc = array();
+    private $classLloc = [];
 
     /**
      * @var array
      */
-    private $methodCcn = array();
+    private $methodCcn = [];
 
     /**
      * @var array
      */
-    private $methodLloc = array();
+    private $methodLloc = [];
 
     /**
      * Processes a set of files.
      *
-     * @param  array   $files
-     * @param  boolean $countTests
+     * @param  array $files
+     * @param  bool  $countTests
      * @return array
      * @since  Method available since Release 1.2.0
      */
@@ -153,7 +149,7 @@ class Analyser
             }
         }
 
-        $directories = array();
+        $directories = [];
 
         foreach ($files as $file) {
             $directory = dirname($file);
@@ -274,8 +270,8 @@ class Analyser
     /**
      * Processes a single file.
      *
-     * @param string  $filename
-     * @param boolean $countTests
+     * @param string $filename
+     * @param bool   $countTests
      */
     public function countFile($filename, $countTests)
     {
@@ -288,7 +284,7 @@ class Analyser
 
         $this->count['files']++;
 
-        $blocks            = array();
+        $blocks            = [];
         $currentBlock      = false;
         $namespace         = false;
         $className         = null;
@@ -342,9 +338,9 @@ class Analyser
                             $functionName = null;
 
                             if ($currentMethodData !== null) {
-                                $this->methodCcn[] = $currentMethodData['ccn'];
+                                $this->methodCcn[]  = $currentMethodData['ccn'];
                                 $this->methodLloc[] = $currentMethodData['lloc'];
-                                $currentMethodData = null;
+                                $currentMethodData  = null;
                             }
                         } elseif ($block == $className) {
                             $className         = null;
@@ -369,7 +365,12 @@ class Analyser
                         $this->namespaces[$namespace] = true;
                     }
                     break;
-
+                    
+                case T_USE;
+                    while($tokens[++$i][0] !== ";" && $i < $numTokens);
+                    $i--;
+                    continue;
+                    
                 case T_CLASS:
                 case T_INTERFACE:
                 case T_TRAIT:
@@ -377,7 +378,7 @@ class Analyser
                         continue;
                     }
 
-                    $currentClassData = array('ccn' => 1, 'lloc' => 0);
+                    $currentClassData = ['ccn' => 1, 'lloc' => 0];
                     $className        = $this->getClassName($namespace, $tokens, $i);
                     $currentBlock     = T_CLASS;
 
@@ -459,7 +460,7 @@ class Analyser
                                 $this->isTestMethod($functionName, $visibility, $static, $tokens, $i)) {
                                 $this->count['testMethods']++;
                             } elseif (!$testClass) {
-                                $currentMethodData = array('ccn' => 1, 'lloc' => 0);
+                                $currentMethodData = ['ccn' => 1, 'lloc' => 0];
 
                                 if (!$static) {
                                     $this->count['nonStaticMethods']++;
@@ -513,15 +514,11 @@ class Analyser
 
                 case T_COMMENT:
                 case T_DOC_COMMENT:
-                    $lf = substr_count($value, "\n");
-
-                    $this->count['cloc'] += $lf;
-
-                    if ($lf > 1) {
-                        $this->count['cloc']++;
-                    }
+                    // We want to count all intermediate lines before the token ends
+                    // But sometimes a new token starts after a newline, we don't want to count that.
+                    // That happend with /* */ and /**  */, but not with // since it'll end at the end
+                    $this->count['cloc'] += substr_count(rtrim($value, "\n"), "\n") + 1;
                     break;
-
                 case T_CONST:
                     $this->count['classConstants']++;
                     break;
@@ -588,8 +585,8 @@ class Analyser
     }
 
     /**
-     * @param  array   $tokens
-     * @param  integer $i
+     * @param  array  $tokens
+     * @param  int    $i
      * @return string
      * @since  Method available since Release 1.3.0
      */
@@ -613,9 +610,9 @@ class Analyser
     }
 
     /**
-     * @param  string  $namespace
-     * @param  array   $tokens
-     * @param  integer $i
+     * @param  string $namespace
+     * @param  array  $tokens
+     * @param  int    $i
      * @return string
      * @since  Method available since Release 1.3.0
      */
@@ -647,14 +644,14 @@ class Analyser
 
     /**
      * @param  string $className
-     * @return boolean
+     * @return bool
      * @since  Method available since Release 1.2.0
      */
     private function isTestClass($className)
     {
         $parent = $this->classes[$className];
         $result = false;
-        $count = 0;
+        $count  = 0;
 
         // Check ancestry for PHPUnit_Framework_TestCase.
         while ($parent !== null) {
@@ -692,12 +689,12 @@ class Analyser
     }
 
     /**
-     * @param  string  $functionName
-     * @param  integer $visibility
-     * @param  boolean $static
-     * @param  array   $tokens
-     * @param  integer $currentToken
-     * @return boolean
+     * @param  string $functionName
+     * @param  int    $visibility
+     * @param  bool   $static
+     * @param  array  $tokens
+     * @param  int    $currentToken
+     * @return bool
      * @since  Method available since Release 2.0.0
      */
     private function isTestMethod($functionName, $visibility, $static, array $tokens, $currentToken)
@@ -723,9 +720,9 @@ class Analyser
     }
 
     /**
-     * @param  array   $tokens
-     * @param  integer $start
-     * @return boolean
+     * @param  array $tokens
+     * @param  int   $start
+     * @return bool
      */
     private function getNextNonWhitespaceTokenPos(array $tokens, $start)
     {
@@ -743,9 +740,9 @@ class Analyser
     }
 
     /**
-     * @param  array   $tokens
-     * @param  integer $start
-     * @return boolean
+     * @param  array $tokens
+     * @param  int   $start
+     * @return bool
      */
     private function getPreviousNonWhitespaceTokenPos(array $tokens, $start)
     {
@@ -763,9 +760,9 @@ class Analyser
     }
 
     /**
-     * @param  array   $tokens
-     * @param  integer $i
-     * @return boolean
+     * @param  array $tokens
+     * @param  int   $i
+     * @return bool
      */
     private function isClassDeclaration(array $tokens, $i)
     {
