@@ -19,17 +19,13 @@ use Symfony\Component\Console\Input\ArrayInput;
 /**
  * TextUI frontend for PHPLOC.
  *
- * @author    Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright Sebastian Bergmann <sebastian@phpunit.de>
- * @license   http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link      http://github.com/sebastianbergmann/phploc/tree
  * @since     Class available since Release 2.0.0
  */
 class Application extends AbstractApplication
 {
     public function __construct()
     {
-        $version = new Version('2.1.3', dirname(dirname(__DIR__)));
+        $version = new Version('3.0.0', dirname(dirname(__DIR__)));
         parent::__construct('phploc', $version->getVersion());
     }
 
@@ -77,7 +73,7 @@ class Application extends AbstractApplication
      * @param InputInterface  $input  An Input instance
      * @param OutputInterface $output An Output instance
      *
-     * @return integer 0 if everything went fine, or an error code
+     * @return int 0 if everything went fine, or an error code
      */
     public function doRun(InputInterface $input, OutputInterface $output)
     {
@@ -96,7 +92,7 @@ class Application extends AbstractApplication
         }
 
         if (!$input->getFirstArgument()) {
-            $input = new ArrayInput(array('--help'));
+            $input = new ArrayInput(['--help']);
         }
 
         parent::doRun($input, $output);
