@@ -25,10 +25,6 @@ use Symfony\Component\Console\Output\OutputInterface;
 use Symfony\Component\Console\Helper\ProgressBar;
 
 /**
- * @author    Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright Sebastian Bergmann <sebastian@phpunit.de>
- * @license   http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link      http://github.com/sebastianbergmann/phploc/tree
  * @since     Class available since Release 2.0.0
  */
 class Command extends AbstractCommand
@@ -40,26 +36,26 @@ class Command extends AbstractCommand
     {
         $this->setName('phploc')
              ->setDefinition(
-                 array(
+                 [
                    new InputArgument(
                        'values',
                        InputArgument::IS_ARRAY
                    )
-                 )
+                 ]
              )
              ->addOption(
                  'names',
                  null,
                  InputOption::VALUE_REQUIRED,
                  'A comma-separated list of file names to check',
-                 array('*.php')
+                 ['*.php']
              )
              ->addOption(
                  'names-exclude',
                  null,
                  InputOption::VALUE_REQUIRED,
                  'A comma-separated list of file names to exclude',
-                 array()
+                 []
              )
              ->addOption(
                  'count-tests',
@@ -105,7 +101,7 @@ class Command extends AbstractCommand
      * @param InputInterface  $input  An InputInterface instance
      * @param OutputInterface $output An OutputInterface instance
      *
-     * @return null|integer null or 0 if everything went fine, or an error code
+     * @return null|int null or 0 if everything went fine, or an error code
      */
     protected function execute(InputInterface $input, OutputInterface $output)
     {
@@ -120,7 +116,7 @@ class Command extends AbstractCommand
      * @param InputInterface  $input  An InputInterface instance
      * @param OutputInterface $output An OutputInterface instance
      *
-     * @return null|integer null or 0 if everything went fine, or an error code
+     * @return null|int null or 0 if everything went fine, or an error code
      */
     private function executeSingle(InputInterface $input, OutputInterface $output)
     {
@@ -160,16 +156,20 @@ class Command extends AbstractCommand
      * @param InputInterface  $input  An InputInterface instance
      * @param OutputInterface $output An OutputInterface instance
      *
-     * @return null|integer null or 0 if everything went fine, or an error code
+     * @return null|int null or 0 if everything went fine, or an error code
      */
     private function executeHistory(InputInterface $input, OutputInterface $output)
     {
         $git            = new Git($input->getOption('git-repository'));
         $currentBranch  = $git->getCurrentBranch();
         $revisions      = $git->getRevisions();
-        $count          = array();
+        $printer        = null;
         $progressBar    = null;
 
+        if ($input->getOption('log-csv')) {
+            $printer = new History($input->getOption('log-csv'));
+        }
+
         if ($input->getOption('progress')) {
             $progressBar = new ProgressBar($output, count($revisions));
             $progressBar->start();
@@ -178,7 +178,7 @@ class Command extends AbstractCommand
         foreach ($revisions as $revision) {
             $git->checkout($revision['sha1']);
 
-            $directories = array();
+            $directories = [];
 
             foreach ($input->getArgument('values') as $value) {
                 $directory = realpath($value);
@@ -198,7 +198,10 @@ class Command extends AbstractCommand
 
             if ($_count) {
                 $_count['commit'] = $revision['sha1'];
-                $count[$revision['date']->format(\DateTime::W3C)] = $_count;
+                $_count['date']   = $revision['date']->format(\DateTime::W3C);
+                if ($printer) {
+                    $printer->printRow($_count);
+                }
             }
 
             if ($progressBar !== null) {
@@ -213,10 +216,6 @@ class Command extends AbstractCommand
             $output->writeln('');
         }
 
-        if ($input->getOption('log-csv')) {
-            $printer = new History;
-            $printer->printResult($input->getOption('log-csv'), $count);
-        }
     }
 
     private function count(array $arguments, $excludes, $names, $namesExclude, $countTests)
