@@ -11,12 +11,6 @@
 /**
  * Tests for the PHPLOC_Analyser class.
  *
- * @package    PHPLOC
- * @subpackage Tests
- * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://github.com/sebastianbergmann/phploc/
  * @since      Class available since Release 1.3.0
  */
 class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
@@ -27,6 +21,11 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
     protected $analyser;
 
     protected function setUp()
+    {
+        $this->resetAnalyser();
+    }
+
+    private function resetAnalyser()
     {
         $this->analyser = new SebastianBergmann\PHPLOC\Analyser;
     }
@@ -34,13 +33,13 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
     public function testWithoutTests()
     {
         $this->assertEquals(
-            array(
+            [
                 'files' => 1,
-                'loc' => 73,
-                'lloc' => 25,
+                'loc' => 75,
+                'lloc' => 26,
                 'llocClasses' => 22,
                 'llocFunctions' => 1,
-                'llocGlobal' => 2,
+                'llocGlobal' => 3,
                 'cloc' => 7,
                 'ccn' => 2,
                 'ccnMethods' => 2,
@@ -76,7 +75,7 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
                 'globalConstantAccesses' => 1,
                 'directories' => 0,
                 'namespaces' => 1,
-                'ncloc' => 66,
+                'ncloc' => 68,
                 'classCcnMin' => 1,
                 'classCcnAvg' => 1.65,
                 'classCcnMax' => 3,
@@ -89,9 +88,9 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
                 'methodLlocMin' => 4,
                 'methodLlocAvg' => 5.6,
                 'methodLlocMax' => 7
-            ),
+            ],
             $this->analyser->countFiles(
-                array(__DIR__ . '/_files/source.php'),
+                [__DIR__ . '/_files/source.php'],
                 false
             ),
             '',
@@ -102,13 +101,13 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
     public function testWithTests()
     {
         $this->assertEquals(
-            array(
+            [
                 'files' => 2,
-                'loc' => 96,
-                'lloc' => 25,
+                'loc' => 98,
+                'lloc' => 26,
                 'llocClasses' => 22,
                 'llocFunctions' => 1,
-                'llocGlobal' => 2,
+                'llocGlobal' => 3,
                 'cloc' => 11,
                 'ccn' => 2,
                 'ccnMethods' => 2,
@@ -144,7 +143,7 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
                 'globalConstantAccesses' => 1,
                 'directories' => 0,
                 'namespaces' => 1,
-                'ncloc' => 85,
+                'ncloc' => 87,
                 'classCcnMin' => 1,
                 'classCcnAvg' => 1.5,
                 'classCcnMax' => 3,
@@ -157,12 +156,12 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
                 'methodLlocMin' => 4,
                 'methodLlocAvg' => 5.6,
                 'methodLlocMax' => 7
-            ),
+            ],
             $this->analyser->countFiles(
-                array(
+                [
                     __DIR__ . '/_files/source.php',
                     __DIR__ . '/_files/tests.php'
-                ),
+                ],
                 true
             ),
             '',
@@ -172,9 +171,9 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
 
     public function testFilesThatExtendPHPUnitTestCaseAreCountedAsTests() {
         $result = $this->analyser->countFiles(
-            array(
+            [
                 __DIR__ . '/_files/tests.php'
-            ),
+            ],
             true
         );
 
@@ -183,24 +182,21 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
 
     public function testFilesThatIndirectlyExtendPHPUnitTestCaseAreCountedAsTests() {
         $result = $this->analyser->countFiles(
-            array(
+            [
                 __DIR__ . '/_files/twoTestsThatIndirectlyExtendPHPUnitTestCase.php'
-            ),
+            ],
             true
         );
 
         $this->assertEquals(3, $result['testClasses']);
     }
 
-    /**
-     * @requires PHP 5.4
-     */
     public function testTraitsAreCountedCorrectly()
     {
         $result = $this->analyser->countFiles(
-            array(
+            [
                 __DIR__ . '/_files/trait.php'
-            ),
+            ],
             false
         );
 
@@ -213,12 +209,59 @@ class PHPLOC_AnalyserTest extends PHPUnit_Framework_TestCase
     public function testIssue64IsFixed()
     {
         $result = $this->analyser->countFiles(
-            array(
+            [
                 __DIR__ . '/_files/issue_62.php'
-            ),
+            ],
             false
         );
 
         $this->assertEquals(1, $result['cloc']);
     }
+
+    /**
+     * @ticket 112
+     */
+    public function testIssue112IsFixed()
+    {
+        $result = $this->analyser->countFiles(
+            array(
+                __DIR__ . '/_files/issue_112.php'
+            ),
+            false
+        );
+
+        $this->assertEquals(5, $result['loc']);
+    }
+
+    /**
+     * @ticket 126
+     * @dataProvider issue126Provider
+     */
+    public function testIssue126IsFixed($fileNumber, $cloc)
+    {
+        $file = __DIR__ . '/_files/issue_126/issue_126_' . $fileNumber . '.php';
+        $result = $this->analyser->countFiles(array($file), false);
+
+        $assertString = sprintf('Failed asserting that %s matches expected %s in issue_126_%d.php',
+                            $result['cloc'],
+                            $cloc,
+                            $fileNumber
+        );
+        $this->assertEquals($cloc, $result['cloc'], $assertString);
+        $this->resetAnalyser();
+    }
+
+    public function issue126Provider()
+    {
+        // issue_126_X.php => CLOC
+        return array(
+            array(1, 1),
+            array(2, 1),
+            array(3, 1),
+            array(4, 2),
+            array(5, 3),
+            array(6, 3),
+            array(7, 3),
+        );
+    }
 }
